nxp-pac

Crates

git

Versions

mcxa577

Flavors

GdetDlyCtrl

Struct GdetDlyCtrl 

#[repr(transparent)]
pub struct GdetDlyCtrl(pub u32);
GDET Delay Control Register

Tuple Fields

0: u32

Implementations

Source

impl GdetDlyCtrl

pub const fn vol_sel(&self) -> u8

GDET Delay Control of the Voltage Mode

pub const fn set_vol_sel(&mut self, val: u8)

GDET Delay Control of the Voltage Mode

pub const fn sw_vol_ctrl(&self) -> bool

Select the Control of the Trim Code to the Delay Line

pub const fn set_sw_vol_ctrl(&mut self, val: bool)

Select the Control of the Trim Code to the Delay Line

pub const fn rfu(&self) -> u32

Reserved for Future Use

pub const fn set_rfu(&mut self, val: u32)

Reserved for Future Use