#[repr(transparent)]pub struct GdetDlyCtrl(pub u32);Expand description
GDET Delay Control Register
Tuple Fields
0: u32Implementations
Sourceimpl GdetDlyCtrl
impl GdetDlyCtrl
Sourcepub const fn set_vol_sel(&mut self, val: u8)
pub const fn set_vol_sel(&mut self, val: u8)
GDET Delay Control of the Voltage Mode
Sourcepub const fn sw_vol_ctrl(&self) -> bool
pub const fn sw_vol_ctrl(&self) -> bool
Select the Control of the Trim Code to the Delay Line
Sourcepub const fn set_sw_vol_ctrl(&mut self, val: bool)
pub const fn set_sw_vol_ctrl(&mut self, val: bool)
Select the Control of the Trim Code to the Delay Line